==> icons-vue-0.3.0.tgz: package/es/distribute--horizontal-right/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../chunk-75bb93d0.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_DistributeHorizontalRight20 = {
  name: 'DistributeHorizontalRight20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M28 2H30V30H28zM24 22H20a2.0021 2.0021 0 0 1-2-2V12a2.0021 2.0021 0 0 1 2-2h4a2.0021 2.0021 0 0 1 2 2v8A2.0021 2.0021 0 0 1 24 22zM20 12h-.0015L20 20h4V12zM12 2H14V30H12zM8 26H4a2.0021 2.0021 0 0 1-2-2V8A2.0021 2.0021 0 0 1 4 6H8a2.0021 2.0021 0 0 1 2 2V24A2.0021 2.0021 0 0 1 8 26zM4 8H3.9985L4 24H8V8z"
      }
    }), children]);
  }
};

export default virtual_DistributeHorizontalRight20;

==> icons-vue-0.6.0.tgz: package/es/distribute--horizontal-right/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_DistributeHorizontalRight20 = {
  name: 'DistributeHorizontalRight20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "28",
        "x": "28",
        "y": "2"
      }
    }), createElement('path', {
      attrs: {
        "d": "M24,22H20a2.0021,2.0021,0,0,1-2-2V12a2.0021,2.0021,0,0,1,2-2h4a2.0021,2.0021,0,0,1,2,2v8A2.0021,2.0021,0,0,1,24,22ZM20,12h-.0015L20,20h4V12Z"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "28",
        "x": "12",
        "y": "2"
      }
    }), createElement('path', {
      attrs: {
        "d": "M8,26H4a2.0021,2.0021,0,0,1-2-2V8A2.0021,2.0021,0,0,1,4,6H8a2.0021,2.0021,0,0,1,2,2V24A2.0021,2.0021,0,0,1,8,26ZM4,8H3.9985L4,24H8V8Z"
      }
    }), children]);
  }
};

export default virtual_DistributeHorizontalRight20;
